api.cases.v1.test_helpers.servicetypes package — Argus-Toolbelt 1.0 documentation

# api.cases.v1.test_helpers.servicetypes package

## Submodules

## api.cases.v1.test_helpers.servicetypes.get module

`api.cases.v1.test_helpers.servicetypes.get.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes, respond with HTTP 403

`api.cases.v1.test_helpers.servicetypes.get.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes, respond with HTTP 404

`api.cases.v1.test_helpers.servicetypes.get.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes, respond with HTTP 200

`api.cases.v1.test_helpers.servicetypes.get.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes, respond with HTTP 401

## api.cases.v1.test_helpers.servicetypes.get_case module

`api.cases.v1.test_helpers.servicetypes.get_case.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes/w+, respond with HTTP 403

`api.cases.v1.test_helpers.servicetypes.get_case.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes/w+, respond with HTTP 404

`api.cases.v1.test_helpers.servicetypes.get_case.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes/w+, respond with HTTP 200

`api.cases.v1.test_helpers.servicetypes.get_case.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/cases/v1/servicetypes/w+, respond with HTTP 401

## Module contents